aboutsummaryrefslogtreecommitdiff
diff options
context:
space:
mode:
authorMatt DeVillier <matt.devillier@gmail.com>2023-06-30 15:04:30 -0500
committerFelix Held <felix-coreboot@felixheld.de>2023-07-28 00:29:18 +0000
commitcb40888c8dc087242ed88a919f14c4324e75bac5 (patch)
treec27069cf30c2a2dc02be7c83e08e1cf04b68346d
parent87f08bea11ecabc721e80d553ff8173c77ae19ab (diff)
mb/google/link: Change HDA verb subsystem ID
Change the SSID to allow the correct Creative Labs Windows audio drivers to attach (vs generic HDA audio ones) and provide full functionality. Linux doesn't care about the SSID, so changing it has no effect there. TEST=build/boot Windows, Linux on google/link, verify the correct audio drivers attach under Windows, no regressions under Linux. Change-Id: Ib5e523b07583289b0222ef156245fb0771ad1f1c Signed-off-by: Matt DeVillier <matt.devillier@gmail.com> Reviewed-on: https://review.coreboot.org/c/coreboot/+/76745 Reviewed-by: Eric Lai <eric_lai@quanta.corp-partner.google.com> Reviewed-by: Sean Rhodes <sean@starlabs.systems> Tested-by: build bot (Jenkins) <no-reply@coreboot.org> Reviewed-by: Paul Menzel <paulepanter@mailbox.org>
-rw-r--r--src/mainboard/google/link/hda_verb.c6
1 files changed, 3 insertions, 3 deletions
diff --git a/src/mainboard/google/link/hda_verb.c b/src/mainboard/google/link/hda_verb.c
index 1f54222ae0..7283e6d8b8 100644
--- a/src/mainboard/google/link/hda_verb.c
+++ b/src/mainboard/google/link/hda_verb.c
@@ -5,7 +5,7 @@
const u32 cim_verb_data[] = {
/* coreboot specific header */
0x11020011, // Codec Vendor / Device ID: Creative CA0132
- 0x144dc0c2, // Subsystem ID
+ 0x10280550, // Subsystem ID
0x00000014, // Number of jacks + Number of Malcolm setup blocks.
/* Malcolm Setup */
@@ -62,8 +62,8 @@ const u32 cim_verb_data[] = {
/* Pin Widget Verb Table */
- /* NID 0x01, HDA Codec Subsystem ID Verb Table: 0x144DC0C2 */
- AZALIA_SUBVENDOR(0, 0x144dc0c2),
+ /* NID 0x01, HDA Codec Subsystem ID Verb Table: 0x10280550 */
+ AZALIA_SUBVENDOR(0, 0x10280550),
/* Pin Complex (NID 0x0B) Port-G Analog Unknown Speaker at Int N/A */
AZALIA_PIN_CFG(0, 0x0b, 0x901700f0),